pub struct HypercomputeCluster { /* private fields */ }Expand description
Implements a client for the Cluster Director API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
async fn sample(
project_id: &str,
location_id: &str,
) -> anyhow::Result<()> {
let client = HypercomputeCluster::builder().build().await?;
let mut list = client.list_clusters()
.set_parent(format!("projects/{project_id}/locations/{location_id}"))
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Service Description
Service describing handlers for resources
Configuration
To configure HypercomputeCluster use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://hypercomputecluster.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured with Private Google Access with VPC Service Controls) may want to override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
HypercomputeCluster holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap HypercomputeCluster in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl HypercomputeCluster
impl HypercomputeCluster
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for HypercomputeCluster.
let client = HypercomputeCluster::builder().build().await?;Sourcepub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: HypercomputeCluster + 'static,
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: HypercomputeCluster + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn list_clusters(&self) -> ListClusters
pub fn list_clusters(&self) -> ListClusters
Lists Clusters in a given project and location.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_hypercomputecluster_v1::Result;
async fn sample(
client: &HypercomputeCluster, project_id: &str, location_id: &str
) -> Result<()> {
let mut list = client.list_clusters()
.set_parent(format!("projects/{project_id}/locations/{location_id}"))
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_cluster(&self) -> GetCluster
pub fn get_cluster(&self) -> GetCluster
Gets details of a single Cluster.
Example
use google_cloud_hypercomputecluster_v1::Result;
async fn sample(
client: &HypercomputeCluster, project_id: &str, location_id: &str, cluster_id: &str
) -> Result<()> {
let response = client.get_cluster()
.set_name(format!("projects/{project_id}/locations/{location_id}/clusters/{cluster_id}"))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_cluster(&self) -> CreateCluster
pub fn create_cluster(&self) -> CreateCluster
Creates a new Cluster in a given project and location.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_hypercomputecluster_v1::model::Cluster;
use google_cloud_hypercomputecluster_v1::Result;
async fn sample(
client: &HypercomputeCluster, project_id: &str, location_id: &str
) -> Result<()> {
let response = client.create_cluster()
.set_parent(format!("projects/{project_id}/locations/{location_id}"))
.set_cluster_id("cluster_id_value")
.set_cluster(
Cluster::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_cluster(&self) -> UpdateCluster
pub fn update_cluster(&self) -> UpdateCluster
Updates the parameters of a single Cluster.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_hypercomputecluster_v1::model::Cluster;
use google_cloud_hypercomputecluster_v1::Result;
async fn sample(
client: &HypercomputeCluster, project_id: &str, location_id: &str, cluster_id: &str
) -> Result<()> {
let response = client.update_cluster()
.set_cluster(
Cluster::new().set_name(format!("projects/{project_id}/locations/{location_id}/clusters/{cluster_id}"))/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_cluster(&self) -> DeleteCluster
pub fn delete_cluster(&self) -> DeleteCluster
Deletes a single Cluster.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_hypercomputecluster_v1::Result;
async fn sample(
client: &HypercomputeCluster, project_id: &str, location_id: &str, cluster_id: &str
) -> Result<()> {
client.delete_cluster()
.set_name(format!("projects/{project_id}/locations/{location_id}/clusters/{cluster_id}"))
.poller().until_done().await?;
Ok(())
}Sourcepub fn list_locations(&self) -> ListLocations
pub fn list_locations(&self) -> ListLocations
Lists information about the supported locations for this service. This method can be called in two ways:
- List all public locations: Use the path
GET /v1/locations. - List project-visible locations: Use the path
GET /v1/projects/{project_id}/locations. This may include public locations as well as private or other locations specifically visible to the project.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_hypercomputecluster_v1::Result;
async fn sample(
client: &HypercomputeCluster
) -> Result<()> {
let mut list = client.list_locations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_location(&self) -> GetLocation
pub fn get_location(&self) -> GetLocation
Gets information about a location.
Example
use google_cloud_hypercomputecluster_v1::Result;
async fn sample(
client: &HypercomputeCluster
) -> Result<()> {
let response = client.get_location()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_hypercomputecluster_v1::Result;
async fn sample(
client: &HypercomputeCluster
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_hypercomputecluster_v1::Result;
async fn sample(
client: &HypercomputeCluster
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_hypercomputecluster_v1::Result;
async fn sample(
client: &HypercomputeCluster
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_hypercomputecluster_v1::Result;
async fn sample(
client: &HypercomputeCluster
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for HypercomputeCluster
impl Clone for HypercomputeCluster
Sourcefn clone(&self) -> HypercomputeCluster
fn clone(&self) -> HypercomputeCluster
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreAuto Trait Implementations
impl !RefUnwindSafe for HypercomputeCluster
impl !UnwindSafe for HypercomputeCluster
impl Freeze for HypercomputeCluster
impl Send for HypercomputeCluster
impl Sync for HypercomputeCluster
impl Unpin for HypercomputeCluster
impl UnsafeUnpin for HypercomputeCluster