Module model

Module model 

The messages and enums that are part of this client library.

Modules

compute_resource_config
Defines additional types related to ComputeResourceConfig.
gcs_autoclass_config
Defines additional types related to GcsAutoclassConfig.
network_resource
Defines additional types related to NetworkResource.
network_resource_config
Defines additional types related to NetworkResourceConfig.
new_bucket_config
Defines additional types related to NewBucketConfig.
new_filestore_config
Defines additional types related to NewFilestoreConfig.
new_reserved_instances_config
Defines additional types related to NewReservedInstancesConfig.
new_spot_instances_config
Defines additional types related to NewSpotInstancesConfig.
operation_step
Defines additional types related to OperationStep.
orchestrator
Defines additional types related to Orchestrator.
slurm_node_set
Defines additional types related to SlurmNodeSet.
storage_resource
Defines additional types related to StorageResource.
storage_resource_config
Defines additional types related to StorageResourceConfig.

Structs

BootDisk
A Persistent disk used as the boot disk for a Compute Engine VM instance.
BucketReference
A reference to a Google Cloud Storage bucket.
CheckClusterHealth
When set in OperationStep, indicates that cluster health check should be performed.
Cluster
A collection of virtual machines and connected resources forming a high-performance computing cluster capable of running large-scale, tightly coupled workloads. A cluster combines a set a compute resources that perform computations, storage resources that contain inputs and store outputs, an orchestrator that is responsible for assigning jobs to compute resources, and network resources that connect everything together.
ComputeInstance
Details about a Compute Engine instance.
ComputeInstanceSlurmNodeSet
When set in a SlurmNodeSet, indicates that the nodeset should be backed by Compute Engine VM instances.
ComputeResource
A resource defining how virtual machines and accelerators should be provisioned for the cluster.
ComputeResourceConfig
Describes how a compute resource should be created at runtime.
CreateClusterRequest
Request message for CreateCluster.
CreateFilestoreInstance
When set in OperationStep, indicates that a new filestore instance should be created.
CreateLoginNode
When set in OperationStep, indicates that a login node should be created.
CreateLustreInstance
When set in OperationStep, indicates that a new lustre instance should be created.
CreateNetwork
When set in OperationStep, indicates that a new network should be created.
CreateNodeset
When set in OperationStep, indicates that a nodeset should be created.
CreateOrchestrator
When set in OperationStep, indicates that an orchestrator should be created.
CreatePartition
When set in OperationStep, indicates that a partition should be created.
CreatePrivateServiceAccess
When set in OperationStep, indicates that a new private service access should be created.
CreateStorageBucket
When set in OperationStep, indicates that a new storage bucket should be created.
DeleteClusterRequest
Request message for DeleteCluster.
DeleteFilestoreInstance
When set in OperationStep, indicates that a Filestore instance should be deleted.
DeleteLoginNode
When set in OperationStep, indicates that a login node should be deleted.
DeleteLustreInstance
When set in OperationStep, indicates that a Lustre instance should be deleted.
DeleteNetwork
When set in OperationStep, indicates network deletion step with the resource name.
DeleteNodeset
When set in OperationStep, indicates that a nodeset should be deleted.
DeleteOrchestrator
When set in OperationStep, indicates that an orchestrator should be deleted.
DeletePartition
When set in OperationStep, indicates that a partition should be deleted.
DeletePrivateServiceAccess
When set in OperationStep, indicates private service access deletion step.
DeleteStorageBucket
When set in OperationStep, indicates that Cloud Storage bucket should be deleted.
ExistingBucketConfig
When set in a StorageResourceConfig, indicates that an existing Google Cloud Storage bucket should be imported.
ExistingFilestoreConfig
When set in a StorageResourceConfig, indicates that an existing Filestore instance should be imported.
ExistingLustreConfig
When set in a StorageResourceConfig, indicates that an existing Managed Lustre instance should be imported.
ExistingNetworkConfig
When set in a NetworkResourceConfig, indicates that an existing network should be imported.
FileShareConfig
Message describing filestore configuration
FilestoreReference
A reference to a Filestore instance.
GcsAutoclassConfig
Message describing Google Cloud Storage autoclass configuration
GcsHierarchicalNamespaceConfig
Message describing Google Cloud Storage hierarchical namespace configuration
GetClusterRequest
Request message for GetCluster.
ListClustersRequest
Request message for ListClusters.
ListClustersResponse
Response message for ListClusters.
LustreReference
A reference to a Managed Lustre instance.
NetworkReference
A reference to a VPC network in Google Compute Engine.
NetworkResource
A resource representing a network that connects the various components of a cluster together.
NetworkResourceConfig
Describes how a network resource should be initialized. Each network resource can either be imported from an existing Google Cloud resource or initialized when the cluster is created.
NewBucketConfig
When set in a StorageResourceConfig, indicates that a new Google Cloud Storage bucket should be created.
NewFilestoreConfig
When set in a StorageResourceConfig, indicates that a new Filestore instance should be created.
NewFlexStartInstancesConfig
When set in a ComputeResourceConfig, indicates that VM instances should be created using Flex Start.
NewLustreConfig
When set in a StorageResourceConfig, indicates that a new Managed Lustre instance should be created.
NewNetworkConfig
When set in a NetworkResourceConfig, indicates that a new network should be created.
NewOnDemandInstancesConfig
When set in a ComputeResourceConfig, indicates that on-demand (i.e., using the standard provisioning model) VM instances should be created.
NewReservedInstancesConfig
When set in a ComputeResourceConfig, indicates that VM instances should be created from a reservation.
NewSpotInstancesConfig
When set in a ComputeResourceConfig, indicates that spot VM instances should be created.
OperationMetadata
Represents the metadata of the long-running operation.
OperationProgress
Message describing the progress of a cluster mutation long-running operation.
OperationStep
Message describing the status of a single step in a cluster mutation long-running operation.
Orchestrator
The component responsible for scheduling and running workloads on the cluster as well as providing the user interface for interacting with the cluster at runtime.
SlurmLoginNodes
Configuration for Slurm login nodes in the cluster. Login nodes are Compute Engine VM instances that allow users to access the cluster over SSH.
SlurmNodeSet
Configuration for Slurm nodesets in the cluster. Nodesets are groups of compute nodes used by Slurm that are responsible for running workloads submitted to the cluster.
SlurmOrchestrator
When set in Orchestrator, indicates that the cluster should use Slurm as the orchestrator.
SlurmPartition
Configuration for Slurm partitions in the cluster. Partitions are groups of nodesets, and are how clients specify where their workloads should be run.
StorageConfig
Description of how a storage resource should be mounted on a VM instance.
StorageResource
A resource representing a form of persistent storage that is accessible to compute resources in the cluster.
StorageResourceConfig
Describes how a storage resource should be initialized. Each storage resource can either be imported from an existing Google Cloud resource or initialized when the cluster is created.
UpdateClusterRequest
Request message for UpdateCluster.
UpdateLoginNode
When set in OperationStep, indicates that a login node should be updated.
UpdateNodeset
When set in OperationStep, indicates that a nodeset should be updated.
UpdateOrchestrator
When set in OperationStep, indicates that an orchestrator should be updated.
UpdatePartition
When set in OperationStep, indicates that a partition should be updated.