#[non_exhaustive]pub struct ComputeResource {
pub config: Option<ComputeResourceConfig>,
/* private fields */
}Expand description
A resource defining how virtual machines and accelerators should be provisioned for the cluster.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.config: Option<ComputeResourceConfig>Required. Immutable. Configuration for this compute resource, which describes how it should be created at runtime.
Implementations
Sourceimpl ComputeResource
impl ComputeResource
Sourcepub fn set_config<T>(self, v: T) -> Selfwhere
T: Into<ComputeResourceConfig>,
pub fn set_config<T>(self, v: T) -> Selfwhere
T: Into<ComputeResourceConfig>,
Sourcepub fn set_or_clear_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<ComputeResourceConfig>,
pub fn set_or_clear_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<ComputeResourceConfig>,
Sets or clears the value of config.
Example
ⓘ
use google_cloud_hypercomputecluster_v1::model::ComputeResourceConfig;
let x = ComputeResource::new().set_or_clear_config(Some(ComputeResourceConfig::default()/* use setters */));
let x = ComputeResource::new().set_or_clear_config(None::<ComputeResourceConfig>);Trait Implementations
Sourceimpl Clone for ComputeResource
impl Clone for ComputeResource
Sourcefn clone(&self) -> ComputeResource
fn clone(&self) -> ComputeResource
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ComputeResource
impl Debug for ComputeResource
Sourceimpl Default for ComputeResource
impl Default for ComputeResource
Sourcefn default() -> ComputeResource
fn default() -> ComputeResource
Returns the “default value” for a type. Read more
Sourceimpl Message for ComputeResource
impl Message for ComputeResource
Sourceimpl PartialEq for ComputeResource
impl PartialEq for ComputeResource
impl StructuralPartialEq for ComputeResource