#[non_exhaustive]pub struct CreateClusterRequest {
pub parent: String,
pub cluster_id: String,
pub cluster: Option<Cluster>,
pub request_id: String,
/* private fields */
}Expand description
Request message for CreateCluster.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. Parent location in which the cluster should be created, in the
format projects/{project}/locations/{location}.
cluster_id: StringRequired. ID of the cluster to create. Must conform to RFC-1034 (lower-case, alphanumeric, and at most 63 characters).
cluster: Option<Cluster>Required. Cluster to create.
request_id: StringOptional. A unique identifier for this request. A random UUID is
recommended. This request is idempotent if and only if request_id is
provided.
Implementations
Sourceimpl CreateClusterRequest
impl CreateClusterRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_cluster_id<T: Into<String>>(self, v: T) -> Self
pub fn set_cluster_id<T: Into<String>>(self, v: T) -> Self
Sets the value of cluster_id.
Example
ⓘ
let x = CreateClusterRequest::new().set_cluster_id("example");Sourcepub fn set_cluster<T>(self, v: T) -> Self
pub fn set_cluster<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_cluster<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_cluster<T>(self, v: Option<T>) -> Self
Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
ⓘ
let x = CreateClusterRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateClusterRequest
impl Clone for CreateClusterRequest
Sourcefn clone(&self) -> CreateClusterRequest
fn clone(&self) -> CreateClusterRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateClusterRequest
impl Debug for CreateClusterRequest
Sourceimpl Default for CreateClusterRequest
impl Default for CreateClusterRequest
Sourcefn default() -> CreateClusterRequest
fn default() -> CreateClusterRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for CreateClusterRequest
impl Message for CreateClusterRequest
Sourceimpl PartialEq for CreateClusterRequest
impl PartialEq for CreateClusterRequest
impl StructuralPartialEq for CreateClusterRequest