#[non_exhaustive]pub struct CreateLustreInstance {
pub lustre: String,
/* private fields */
}Expand description
When set in OperationStep, indicates that a new lustre instance should be created.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.lustre: StringOutput only. Name of the Managed Lustre instance, in the format
projects/{project}/locations/{location}/instances/{instance}
Implementations