#[non_exhaustive]pub struct CreateNetwork {
pub network: String,
/* private fields */
}Expand description
When set in OperationStep, indicates that a new network should be created.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.network: StringOutput only. Name of the network to create, in the format
projects/{project}/global/networks/{network}.
Implementations