#[non_exhaustive]pub struct ExistingFilestoreConfig {
pub filestore: String,
/* private fields */
}Expand description
When set in a StorageResourceConfig, indicates that an existing Filestore instance should be imported.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.filestore: StringRequired. Immutable. Name of the Filestore instance to import, in the
format projects/{project}/locations/{location}/instances/{instance}
Implementations