NewFilestoreConfig

Struct NewFilestoreConfig 

#[non_exhaustive]
pub struct NewFilestoreConfig { pub filestore: String, pub description: String, pub file_shares: Vec<FileShareConfig>, pub tier: Tier, pub protocol: Protocol, /* private fields */ }
When set in a StorageResourceConfig, indicates that a new Filestore instance should be created.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
filestore: String

Required. Immutable. Name of the Filestore instance to create, in the format projects/{project}/locations/{location}/instances/{instance}

description: String

Optional. Immutable. Description of the instance. Maximum of 2048 characters.

file_shares: Vec<FileShareConfig>

Required. Immutable. File system shares on the instance. Exactly one file share must be specified.

tier: Tier

Required. Immutable. Service tier to use for the instance.

protocol: Protocol

Optional. Immutable. Access protocol to use for all file shares in the instance. Defaults to NFS V3 if not set.

Implementations

Source

impl NewFilestoreConfig

pub fn new() -> Self

Creates a new default instance.

pub fn set_filestore<T: Into<String>>(self, v: T) -> Self

Sets the value of filestore.

Example
let x = NewFilestoreConfig::new().set_filestore("example");
pub fn set_description<T: Into<String>>(self, v: T) -> Self

Sets the value of description.

Example
let x = NewFilestoreConfig::new().set_description("example");
pub fn set_file_shares<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<FileShareConfig>,

Sets the value of file_shares.

Example
use google_cloud_hypercomputecluster_v1::model::FileShareConfig;
let x = NewFilestoreConfig::new()
    .set_file_shares([
        FileShareConfig::default()/* use setters */,
        FileShareConfig::default()/* use (different) setters */,
    ]);
pub fn set_tier<T: Into<Tier>>(self, v: T) -> Self

Sets the value of tier.

Example
use google_cloud_hypercomputecluster_v1::model::new_filestore_config::Tier;
let x0 = NewFilestoreConfig::new().set_tier(Tier::Zonal);
let x1 = NewFilestoreConfig::new().set_tier(Tier::Regional);
pub fn set_protocol<T: Into<Protocol>>(self, v: T) -> Self

Sets the value of protocol.

Example
use google_cloud_hypercomputecluster_v1::model::new_filestore_config::Protocol;
let x0 = NewFilestoreConfig::new().set_protocol(Protocol::Nfsv3);
let x1 = NewFilestoreConfig::new().set_protocol(Protocol::Nfsv41);