#[non_exhaustive]pub struct NewFlexStartInstancesConfig {
pub zone: String,
pub machine_type: String,
pub max_duration: Option<Duration>,
/* private fields */
}Expand description
When set in a ComputeResourceConfig, indicates that VM instances should be created using Flex Start.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.zone: StringRequired. Immutable. Name of the zone in which VM instances should run,
e.g., us-central1-a. Must be in the same region as the cluster, and must
match the zone of any other resources specified in the cluster.
machine_type: StringRequired. Immutable. Name of the Compute Engine machine
type to use, e.g.
n2-standard-2.
max_duration: Option<Duration>Required. Immutable. Specifies the time limit for created instances. Instances will be terminated at the end of this duration.
Implementations
Sourceimpl NewFlexStartInstancesConfig
impl NewFlexStartInstancesConfig
Sourcepub fn set_machine_type<T: Into<String>>(self, v: T) -> Self
pub fn set_machine_type<T: Into<String>>(self, v: T) -> Self
Sets the value of machine_type.
Example
ⓘ
let x = NewFlexStartInstancesConfig::new().set_machine_type("example");Sourcepub fn set_max_duration<T>(self, v: T) -> Self
pub fn set_max_duration<T>(self, v: T) -> Self
Sets the value of max_duration.
Example
ⓘ
use wkt::Duration;
let x = NewFlexStartInstancesConfig::new().set_max_duration(Duration::default()/* use setters */);Sourcepub fn set_or_clear_max_duration<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_max_duration<T>(self, v: Option<T>) -> Self
Sets or clears the value of max_duration.
Example
ⓘ
use wkt::Duration;
let x = NewFlexStartInstancesConfig::new().set_or_clear_max_duration(Some(Duration::default()/* use setters */));
let x = NewFlexStartInstancesConfig::new().set_or_clear_max_duration(None::<Duration>);Trait Implementations
Sourceimpl Clone for NewFlexStartInstancesConfig
impl Clone for NewFlexStartInstancesConfig
Sourcefn clone(&self) -> NewFlexStartInstancesConfig
fn clone(&self) -> NewFlexStartInstancesConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NewFlexStartInstancesConfig
impl Debug for NewFlexStartInstancesConfig
Sourceimpl Default for NewFlexStartInstancesConfig
impl Default for NewFlexStartInstancesConfig
Sourcefn default() -> NewFlexStartInstancesConfig
fn default() -> NewFlexStartInstancesConfig
Returns the “default value” for a type. Read more
impl StructuralPartialEq for NewFlexStartInstancesConfig