#[non_exhaustive]pub struct Orchestrator {
pub option: Option<Option>,
/* private fields */
}Expand description
The component responsible for scheduling and running workloads on the cluster as well as providing the user interface for interacting with the cluster at runtime.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.option: Option<Option>Particular type of orchestrator to use in this cluster.
Implementations
Sourceimpl Orchestrator
impl Orchestrator
Sourcepub fn set_option<T: Into<Option<Option>>>(self, v: T) -> Self
pub fn set_option<T: Into<Option<Option>>>(self, v: T) -> Self
Sets the value of option.
Note that all the setters affecting option are mutually
exclusive.
Example
ⓘ
use google_cloud_hypercomputecluster_v1::model::SlurmOrchestrator;
let x = Orchestrator::new().set_option(Some(
google_cloud_hypercomputecluster_v1::model::orchestrator::Option::Slurm(SlurmOrchestrator::default().into())));Sourcepub fn slurm(&self) -> Option<&Box<SlurmOrchestrator>>
pub fn slurm(&self) -> Option<&Box<SlurmOrchestrator>>
The value of option
if it holds a Slurm, None if the field is not set or
holds a different branch.
Sourcepub fn set_slurm<T: Into<Box<SlurmOrchestrator>>>(self, v: T) -> Self
pub fn set_slurm<T: Into<Box<SlurmOrchestrator>>>(self, v: T) -> Self
Sets the value of option
to hold a Slurm.
Note that all the setters affecting option are
mutually exclusive.
Example
ⓘ
use google_cloud_hypercomputecluster_v1::model::SlurmOrchestrator;
let x = Orchestrator::new().set_slurm(SlurmOrchestrator::default()/* use setters */);
assert!(x.slurm().is_some());Trait Implementations
Sourceimpl Clone for Orchestrator
impl Clone for Orchestrator
Sourcefn clone(&self) -> Orchestrator
fn clone(&self) -> Orchestrator
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Orchestrator
impl Debug for Orchestrator
Sourceimpl Default for Orchestrator
impl Default for Orchestrator
Sourcefn default() -> Orchestrator
fn default() -> Orchestrator
Returns the “default value” for a type. Read more
Sourceimpl Message for Orchestrator
impl Message for Orchestrator
Sourceimpl PartialEq for Orchestrator
impl PartialEq for Orchestrator
impl StructuralPartialEq for Orchestrator