#[non_exhaustive]pub struct SlurmPartition {
pub id: String,
pub node_set_ids: Vec<String>,
/* private fields */
}Expand description
Configuration for Slurm partitions in the cluster. Partitions are groups of nodesets, and are how clients specify where their workloads should be run.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: StringRequired. ID of the partition, which is how users will identify it. Must conform to RFC-1034 (lower-case, alphanumeric, and at most 63 characters).
node_set_ids: Vec<String>Required. IDs of the nodesets that make up this partition. Values must match SlurmNodeSet.id.
Implementations
Sourceimpl SlurmPartition
impl SlurmPartition
Sourcepub fn set_node_set_ids<T, V>(self, v: T) -> Self
pub fn set_node_set_ids<T, V>(self, v: T) -> Self
Sets the value of node_set_ids.
Example
ⓘ
let x = SlurmPartition::new().set_node_set_ids(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for SlurmPartition
impl Clone for SlurmPartition
Sourcefn clone(&self) -> SlurmPartition
fn clone(&self) -> SlurmPartition
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SlurmPartition
impl Debug for SlurmPartition
Sourceimpl Default for SlurmPartition
impl Default for SlurmPartition
Sourcefn default() -> SlurmPartition
fn default() -> SlurmPartition
Returns the “default value” for a type. Read more
Sourceimpl Message for SlurmPartition
impl Message for SlurmPartition
Sourceimpl PartialEq for SlurmPartition
impl PartialEq for SlurmPartition
impl StructuralPartialEq for SlurmPartition