#[non_exhaustive]pub struct StorageConfig {
pub id: String,
pub local_mount: String,
/* private fields */
}Expand description
Description of how a storage resource should be mounted on a VM instance.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: StringRequired. ID of the storage resource to mount, which must match a key in the cluster’s storage_resources.
local_mount: StringRequired. A directory inside the VM instance’s file system where the
storage resource should be mounted (e.g., /mnt/share).
Implementations