#[non_exhaustive]pub struct StorageResourceConfig {
pub config: Option<Config>,
/* private fields */
}Expand description
Describes how a storage resource should be initialized. Each storage resource can either be imported from an existing Google Cloud resource or initialized when the cluster is created.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.config: Option<Config>Particular type of configuration for this storage resource.
Implementations
Sourceimpl StorageResourceConfig
impl StorageResourceConfig
Sourcepub fn set_config<T: Into<Option<Config>>>(self, v: T) -> Self
pub fn set_config<T: Into<Option<Config>>>(self, v: T) -> Self
Sets the value of config.
Note that all the setters affecting config are mutually
exclusive.
Example
use google_cloud_hypercomputecluster_v1::model::NewFilestoreConfig;
let x = StorageResourceConfig::new().set_config(Some(
google_cloud_hypercomputecluster_v1::model::storage_resource_config::Config::NewFilestore(NewFilestoreConfig::default().into())));Sourcepub fn new_filestore(&self) -> Option<&Box<NewFilestoreConfig>>
pub fn new_filestore(&self) -> Option<&Box<NewFilestoreConfig>>
The value of config
if it holds a NewFilestore, None if the field is not set or
holds a different branch.
Sourcepub fn set_new_filestore<T: Into<Box<NewFilestoreConfig>>>(self, v: T) -> Self
pub fn set_new_filestore<T: Into<Box<NewFilestoreConfig>>>(self, v: T) -> Self
Sets the value of config
to hold a NewFilestore.
Note that all the setters affecting config are
mutually exclusive.
Example
use google_cloud_hypercomputecluster_v1::model::NewFilestoreConfig;
let x = StorageResourceConfig::new().set_new_filestore(NewFilestoreConfig::default()/* use setters */);
assert!(x.new_filestore().is_some());
assert!(x.existing_filestore().is_none());
assert!(x.new_bucket().is_none());
assert!(x.existing_bucket().is_none());
assert!(x.new_lustre().is_none());
assert!(x.existing_lustre().is_none());Sourcepub fn existing_filestore(&self) -> Option<&Box<ExistingFilestoreConfig>>
pub fn existing_filestore(&self) -> Option<&Box<ExistingFilestoreConfig>>
The value of config
if it holds a ExistingFilestore, None if the field is not set or
holds a different branch.
Sourcepub fn set_existing_filestore<T: Into<Box<ExistingFilestoreConfig>>>(
self,
v: T,
) -> Self
pub fn set_existing_filestore<T: Into<Box<ExistingFilestoreConfig>>>( self, v: T, ) -> Self
Sets the value of config
to hold a ExistingFilestore.
Note that all the setters affecting config are
mutually exclusive.
Example
use google_cloud_hypercomputecluster_v1::model::ExistingFilestoreConfig;
let x = StorageResourceConfig::new().set_existing_filestore(ExistingFilestoreConfig::default()/* use setters */);
assert!(x.existing_filestore().is_some());
assert!(x.new_filestore().is_none());
assert!(x.new_bucket().is_none());
assert!(x.existing_bucket().is_none());
assert!(x.new_lustre().is_none());
assert!(x.existing_lustre().is_none());Sourcepub fn new_bucket(&self) -> Option<&Box<NewBucketConfig>>
pub fn new_bucket(&self) -> Option<&Box<NewBucketConfig>>
The value of config
if it holds a NewBucket, None if the field is not set or
holds a different branch.
Sourcepub fn set_new_bucket<T: Into<Box<NewBucketConfig>>>(self, v: T) -> Self
pub fn set_new_bucket<T: Into<Box<NewBucketConfig>>>(self, v: T) -> Self
Sets the value of config
to hold a NewBucket.
Note that all the setters affecting config are
mutually exclusive.
Example
use google_cloud_hypercomputecluster_v1::model::NewBucketConfig;
let x = StorageResourceConfig::new().set_new_bucket(NewBucketConfig::default()/* use setters */);
assert!(x.new_bucket().is_some());
assert!(x.new_filestore().is_none());
assert!(x.existing_filestore().is_none());
assert!(x.existing_bucket().is_none());
assert!(x.new_lustre().is_none());
assert!(x.existing_lustre().is_none());Sourcepub fn existing_bucket(&self) -> Option<&Box<ExistingBucketConfig>>
pub fn existing_bucket(&self) -> Option<&Box<ExistingBucketConfig>>
The value of config
if it holds a ExistingBucket, None if the field is not set or
holds a different branch.
Sourcepub fn set_existing_bucket<T: Into<Box<ExistingBucketConfig>>>(
self,
v: T,
) -> Self
pub fn set_existing_bucket<T: Into<Box<ExistingBucketConfig>>>( self, v: T, ) -> Self
Sets the value of config
to hold a ExistingBucket.
Note that all the setters affecting config are
mutually exclusive.
Example
use google_cloud_hypercomputecluster_v1::model::ExistingBucketConfig;
let x = StorageResourceConfig::new().set_existing_bucket(ExistingBucketConfig::default()/* use setters */);
assert!(x.existing_bucket().is_some());
assert!(x.new_filestore().is_none());
assert!(x.existing_filestore().is_none());
assert!(x.new_bucket().is_none());
assert!(x.new_lustre().is_none());
assert!(x.existing_lustre().is_none());Sourcepub fn new_lustre(&self) -> Option<&Box<NewLustreConfig>>
pub fn new_lustre(&self) -> Option<&Box<NewLustreConfig>>
The value of config
if it holds a NewLustre, None if the field is not set or
holds a different branch.
Sourcepub fn set_new_lustre<T: Into<Box<NewLustreConfig>>>(self, v: T) -> Self
pub fn set_new_lustre<T: Into<Box<NewLustreConfig>>>(self, v: T) -> Self
Sets the value of config
to hold a NewLustre.
Note that all the setters affecting config are
mutually exclusive.
Example
use google_cloud_hypercomputecluster_v1::model::NewLustreConfig;
let x = StorageResourceConfig::new().set_new_lustre(NewLustreConfig::default()/* use setters */);
assert!(x.new_lustre().is_some());
assert!(x.new_filestore().is_none());
assert!(x.existing_filestore().is_none());
assert!(x.new_bucket().is_none());
assert!(x.existing_bucket().is_none());
assert!(x.existing_lustre().is_none());Sourcepub fn existing_lustre(&self) -> Option<&Box<ExistingLustreConfig>>
pub fn existing_lustre(&self) -> Option<&Box<ExistingLustreConfig>>
The value of config
if it holds a ExistingLustre, None if the field is not set or
holds a different branch.
Sourcepub fn set_existing_lustre<T: Into<Box<ExistingLustreConfig>>>(
self,
v: T,
) -> Self
pub fn set_existing_lustre<T: Into<Box<ExistingLustreConfig>>>( self, v: T, ) -> Self
Sets the value of config
to hold a ExistingLustre.
Note that all the setters affecting config are
mutually exclusive.
Example
use google_cloud_hypercomputecluster_v1::model::ExistingLustreConfig;
let x = StorageResourceConfig::new().set_existing_lustre(ExistingLustreConfig::default()/* use setters */);
assert!(x.existing_lustre().is_some());
assert!(x.new_filestore().is_none());
assert!(x.existing_filestore().is_none());
assert!(x.new_bucket().is_none());
assert!(x.existing_bucket().is_none());
assert!(x.new_lustre().is_none());Trait Implementations
Sourceimpl Clone for StorageResourceConfig
impl Clone for StorageResourceConfig
Sourcefn clone(&self) -> StorageResourceConfig
fn clone(&self) -> StorageResourceConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for StorageResourceConfig
impl Debug for StorageResourceConfig
Sourceimpl Default for StorageResourceConfig
impl Default for StorageResourceConfig
Sourcefn default() -> StorageResourceConfig
fn default() -> StorageResourceConfig
Sourceimpl Message for StorageResourceConfig
impl Message for StorageResourceConfig
Sourceimpl PartialEq for StorageResourceConfig
impl PartialEq for StorageResourceConfig
impl StructuralPartialEq for StorageResourceConfig