The messages and enums that are part of this client library.
Modules
- compute_
resource_ config - Defines additional types related to ComputeResourceConfig.
- gcs_
autoclass_ config - Defines additional types related to GcsAutoclassConfig.
- network_
resource - Defines additional types related to NetworkResource.
- network_
resource_ config - Defines additional types related to NetworkResourceConfig.
- new_
bucket_ config - Defines additional types related to NewBucketConfig.
- new_
filestore_ config - Defines additional types related to NewFilestoreConfig.
- new_
reserved_ instances_ config - Defines additional types related to NewReservedInstancesConfig.
- new_
spot_ instances_ config - Defines additional types related to NewSpotInstancesConfig.
- operation_
step - Defines additional types related to OperationStep.
- orchestrator
- Defines additional types related to Orchestrator.
- slurm_
node_ set - Defines additional types related to SlurmNodeSet.
- storage_
resource - Defines additional types related to StorageResource.
- storage_
resource_ config - Defines additional types related to StorageResourceConfig.
Structs
- Boot
Disk - A Persistent disk used as the boot disk for a Compute Engine VM instance.
- Bucket
Reference - A reference to a Google Cloud Storage bucket.
- Check
Cluster Health - When set in OperationStep, indicates that cluster health check should be performed.
- Cluster
- A collection of virtual machines and connected resources forming a high-performance computing cluster capable of running large-scale, tightly coupled workloads. A cluster combines a set a compute resources that perform computations, storage resources that contain inputs and store outputs, an orchestrator that is responsible for assigning jobs to compute resources, and network resources that connect everything together.
- Compute
Instance - Details about a Compute Engine instance.
- Compute
Instance Slurm Node Set - When set in a SlurmNodeSet, indicates that the nodeset should be backed by Compute Engine VM instances.
- Compute
Resource - A resource defining how virtual machines and accelerators should be provisioned for the cluster.
- Compute
Resource Config - Describes how a compute resource should be created at runtime.
- Create
Cluster Request - Request message for CreateCluster.
- Create
Filestore Instance - When set in OperationStep, indicates that a new filestore instance should be created.
- Create
Login Node - When set in OperationStep, indicates that a login node should be created.
- Create
Lustre Instance - When set in OperationStep, indicates that a new lustre instance should be created.
- Create
Network - When set in OperationStep, indicates that a new network should be created.
- Create
Nodeset - When set in OperationStep, indicates that a nodeset should be created.
- Create
Orchestrator - When set in OperationStep, indicates that an orchestrator should be created.
- Create
Partition - When set in OperationStep, indicates that a partition should be created.
- Create
Private Service Access - When set in OperationStep, indicates that a new private service access should be created.
- Create
Storage Bucket - When set in OperationStep, indicates that a new storage bucket should be created.
- Delete
Cluster Request - Request message for DeleteCluster.
- Delete
Filestore Instance - When set in OperationStep, indicates that a Filestore instance should be deleted.
- Delete
Login Node - When set in OperationStep, indicates that a login node should be deleted.
- Delete
Lustre Instance - When set in OperationStep, indicates that a Lustre instance should be deleted.
- Delete
Network - When set in OperationStep, indicates network deletion step with the resource name.
- Delete
Nodeset - When set in OperationStep, indicates that a nodeset should be deleted.
- Delete
Orchestrator - When set in OperationStep, indicates that an orchestrator should be deleted.
- Delete
Partition - When set in OperationStep, indicates that a partition should be deleted.
- Delete
Private Service Access - When set in OperationStep, indicates private service access deletion step.
- Delete
Storage Bucket - When set in OperationStep, indicates that Cloud Storage bucket should be deleted.
- Existing
Bucket Config - When set in a StorageResourceConfig, indicates that an existing Google Cloud Storage bucket should be imported.
- Existing
Filestore Config - When set in a StorageResourceConfig, indicates that an existing Filestore instance should be imported.
- Existing
Lustre Config - When set in a StorageResourceConfig, indicates that an existing Managed Lustre instance should be imported.
- Existing
Network Config - When set in a NetworkResourceConfig, indicates that an existing network should be imported.
- File
Share Config - Message describing filestore configuration
- Filestore
Reference - A reference to a Filestore instance.
- GcsAutoclass
Config - Message describing Google Cloud Storage autoclass configuration
- GcsHierarchical
Namespace Config - Message describing Google Cloud Storage hierarchical namespace configuration
- GetCluster
Request - Request message for GetCluster.
- List
Clusters Request - Request message for ListClusters.
- List
Clusters Response - Response message for ListClusters.
- Lustre
Reference - A reference to a Managed Lustre instance.
- Network
Reference - A reference to a VPC network in Google Compute Engine.
- Network
Resource - A resource representing a network that connects the various components of a cluster together.
- Network
Resource Config - Describes how a network resource should be initialized. Each network resource can either be imported from an existing Google Cloud resource or initialized when the cluster is created.
- NewBucket
Config - When set in a StorageResourceConfig, indicates that a new Google Cloud Storage bucket should be created.
- NewFilestore
Config - When set in a StorageResourceConfig, indicates that a new Filestore instance should be created.
- NewFlex
Start Instances Config - When set in a ComputeResourceConfig, indicates that VM instances should be created using Flex Start.
- NewLustre
Config - When set in a StorageResourceConfig, indicates that a new Managed Lustre instance should be created.
- NewNetwork
Config - When set in a NetworkResourceConfig, indicates that a new network should be created.
- NewOn
Demand Instances Config - When set in a ComputeResourceConfig, indicates that on-demand (i.e., using the standard provisioning model) VM instances should be created.
- NewReserved
Instances Config - When set in a ComputeResourceConfig, indicates that VM instances should be created from a reservation.
- NewSpot
Instances Config - When set in a ComputeResourceConfig, indicates that spot VM instances should be created.
- Operation
Metadata - Represents the metadata of the long-running operation.
- Operation
Progress - Message describing the progress of a cluster mutation long-running operation.
- Operation
Step - Message describing the status of a single step in a cluster mutation long-running operation.
- Orchestrator
- The component responsible for scheduling and running workloads on the cluster as well as providing the user interface for interacting with the cluster at runtime.
- Slurm
Login Nodes - Configuration for Slurm login nodes in the cluster. Login nodes are Compute Engine VM instances that allow users to access the cluster over SSH.
- Slurm
Node Set - Configuration for Slurm nodesets in the cluster. Nodesets are groups of compute nodes used by Slurm that are responsible for running workloads submitted to the cluster.
- Slurm
Orchestrator - When set in Orchestrator, indicates that the cluster should use Slurm as the orchestrator.
- Slurm
Partition - Configuration for Slurm partitions in the cluster. Partitions are groups of nodesets, and are how clients specify where their workloads should be run.
- Storage
Config - Description of how a storage resource should be mounted on a VM instance.
- Storage
Resource - A resource representing a form of persistent storage that is accessible to compute resources in the cluster.
- Storage
Resource Config - Describes how a storage resource should be initialized. Each storage resource can either be imported from an existing Google Cloud resource or initialized when the cluster is created.
- Update
Cluster Request - Request message for UpdateCluster.
- Update
Login Node - When set in OperationStep, indicates that a login node should be updated.
- Update
Nodeset - When set in OperationStep, indicates that a nodeset should be updated.
- Update
Orchestrator - When set in OperationStep, indicates that an orchestrator should be updated.
- Update
Partition - When set in OperationStep, indicates that a partition should be updated.