#[non_exhaustive]pub struct NewFilestoreConfig {
pub filestore: String,
pub description: String,
pub file_shares: Vec<FileShareConfig>,
pub tier: Tier,
pub protocol: Protocol,
/* private fields */
}Expand description
When set in a StorageResourceConfig, indicates that a new Filestore instance should be created.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.filestore: StringRequired. Immutable. Name of the Filestore instance to create, in the
format projects/{project}/locations/{location}/instances/{instance}
description: StringOptional. Immutable. Description of the instance. Maximum of 2048 characters.
Required. Immutable. File system shares on the instance. Exactly one file share must be specified.
tier: TierRequired. Immutable. Service tier to use for the instance.
protocol: ProtocolOptional. Immutable. Access protocol to use for all file shares in the instance. Defaults to NFS V3 if not set.
Implementations
Sourceimpl NewFilestoreConfig
impl NewFilestoreConfig
Sourcepub fn set_filestore<T: Into<String>>(self, v: T) -> Self
pub fn set_filestore<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sets the value of description.
Example
ⓘ
let x = NewFilestoreConfig::new().set_description("example");Sets the value of file_shares.
Example
ⓘ
use google_cloud_hypercomputecluster_v1::model::FileShareConfig;
let x = NewFilestoreConfig::new()
.set_file_shares([
FileShareConfig::default()/* use setters */,
FileShareConfig::default()/* use (different) setters */,
]);Sourcepub fn set_protocol<T: Into<Protocol>>(self, v: T) -> Self
pub fn set_protocol<T: Into<Protocol>>(self, v: T) -> Self